==> AsposeCellsCloud-CellsApi-25.12.tar.gz: AsposeCellsCloud-CellsApi-25.12/docs/model/PdfSaveOptions.md <==
# AsposeCellsCloud::Object::PdfSaveOptions 

## Load the model package
```perl
use AsposeCellsCloud::Object::PdfSaveOptions;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**DisplayDocTitle** | **boolean** |  |
**ExportDocumentStructure** | **boolean** |  |
**EmfRenderSetting** | **string** |  |
**CustomPropertiesExport** | **string** |  |
**OptimizationType** | **string** |  |
**Producer** | **string** |  |
**PdfCompression** | **string** |  |
**FontEncoding** | **string** |  |
**Watermark** | **RenderingWatermark** |  |
**CalculateFormula** | **boolean** |  |
**CheckFontCompatibility** | **boolean** |  |
**Compliance** | **string** |  |
**DefaultFont** | **string** |  |
**OnePagePerSheet** | **boolean** |  |
**PrintingPageType** | **string** |  |
**SecurityOptions** | **PdfSecurityOptions** |  |
**desiredPPI** | **int** |  |
**jpegQuality** | **int** |  |
**ImageType** | **string** |  |
**SaveFormat** | **string** |  |
**CachedFileFolder** | **string** |  |
**ClearData** | **boolean** |  |
**CreateDirectory** | **boolean** |  |
**EnableHTTPCompression** | **boolean** |  |
**RefreshChartCache** | **boolean** |  |
**SortNames** | **boolean** |  |
**ValidateMergedAreas** | **boolean** |  |
**MergeAreas** | **boolean** |  |
**SortExternalNames** | **boolean** |  |
**CheckExcelRestriction** | **boolean** |  |
**UpdateSmartArt** | **boolean** |  |
**EncryptDocumentProperties** | **boolean** |  |  

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> AsposeCellsCloud-CellsApi-26.2.tar.gz: AsposeCellsCloud-CellsApi-26.2/docs/model/PdfSaveOptions.md <==
# AsposeCellsCloud::Object::PdfSaveOptions 

## Load the model package
```perl
use AsposeCellsCloud::Object::PdfSaveOptions;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**DisplayDocTitle** | **boolean** |  |
**ExportDocumentStructure** | **boolean** |  |
**EmfRenderSetting** | **string** |  |
**CustomPropertiesExport** | **string** |  |
**OptimizationType** | **string** |  |
**Producer** | **string** |  |
**PdfCompression** | **string** |  |
**FontEncoding** | **string** |  |
**Watermark** | **RenderingWatermark** |  |
**CalculateFormula** | **boolean** |  |
**CheckFontCompatibility** | **boolean** |  |
**Compliance** | **string** |  |
**DefaultFont** | **string** |  |
**OnePagePerSheet** | **boolean** |  |
**PrintingPageType** | **string** |  |
**SecurityOptions** | **PdfSecurityOptions** |  |
**desiredPPI** | **int** |  |
**jpegQuality** | **int** |  |
**ImageType** | **string** |  |
**SaveFormat** | **string** |  |
**CachedFileFolder** | **string** |  |
**ClearData** | **boolean** |  |
**CreateDirectory** | **boolean** |  |
**EnableHTTPCompression** | **boolean** |  |
**RefreshChartCache** | **boolean** |  |
**SortNames** | **boolean** |  |
**ValidateMergedAreas** | **boolean** |  |
**MergeAreas** | **boolean** |  |
**SortExternalNames** | **boolean** |  |
**CheckExcelRestriction** | **boolean** |  |
**UpdateSmartArt** | **boolean** |  |
**EncryptDocumentProperties** | **boolean** |  |  


[[Back to Model list]](../DeveloperGuide.md#model-reference)  
[[Back to README]](../../README.md)
